"use strict";
var Rx_1 = require("rxjs/Rx");
/**
 * Wrapped http services as a common interface.
 * HttpHarness allows you to separate a DI process and a http process.
 *
 *
 * ## Shared code: `TestService` as an abstract class
 *
 * ```
 * export abstract class TestService {
 *    private http: HttpHarness;
 *
 *    constructor(http: HttpHarness) {
 *        this.http = http;
 *    }
 *
 *    get(id: string): Observable<any> {
 *        return this.http.get(`/${id}`);
 *    }
 * }
 * ```
 *
 * ## Angular 1 code: `Ng1TestService` as an entry point for `$http`
 * Use `angular-http-harness/ng1`
 *
 * ```
 * import {HttpHarness} from "angular-http-harness";
 * import {fromNg1} from "angular-http-harness/ng1";
 *
 * export class Ng1TestService extends TestService {
 *
 *     constructor($http: angular.IHttpService) {
 *         super(new HttpHarness(fromNg1($http)));
 *     }
 *
 *     get(id: string): Observable<TestModel> {
 *         return super.get(id).map(resp => resp.data);
 *     }
 * }
 *
 * angular.module("app").service("testService", ["$http", Ng1TestService]);
 * ```
 *
 */
function fromNg1($http) {
    return {
        get: function (url, options) {
            return wrapNg1Promise($http.get(url, options));
        },
        post: function (url, body, options) {
            return wrapNg1Promise($http.post(url, body, options));
        },
        put: function (url, body, options) {
            return wrapNg1Promise($http.put(url, body, options));
        },
        delete: function (url, options) {
            return wrapNg1Promise($http.delete(url, options));
        },
    };
}
exports.fromNg1 = fromNg1;
function wrapNg1Promise(p) {
    return Rx_1.Observable.create(function (observer) {
        p.then(function (resp) {
            observer.next(resp);
            observer.complete();
        }).catch(function (resp) {
            observer.error(resp);
        });
    });
}
