"use strict";
/**
 * Wrapped http services as a common interface.
 * HttpHarness allows you to separate a DI process and a http process.
 *
 *
 * ## Shared code: `TestService` as an abstract class
 *
 * ```
 * import {HttpHarness} from "angular-http-harness";
 *
 * export abstract class TestService {
 *    private http: HttpHarness;
 *
 *    constructor(http: HttpHarness) {
 *        this.http = http;
 *    }
 *
 *    get(id: string): Observable<any> {
 *        return this.http.get(`/${id}`);
 *    }
 * }
 * ```
 *
 * ## Angular 1 code: `Ng1TestService` as an entry point for `$http`
 * Use `angular-http-harness/ng1`
 *
 * ```
 * import {HttpHarness} from "angular-http-harness";
 * import {fromNg1} from "angular-http-harness/ng1";
 *
 * export class Ng1TestService extends TestService {
 *
 *     constructor($http: angular.IHttpService) {
 *         super(new HttpHarness(fromNg1($http)));
 *     }
 *
 *     get(id: string): Observable<TestModel> {
 *         return super.get(id).map(resp => resp.data);
 *     }
 * }
 *
 * angular.module("app").service("testService", ["$http", Ng1TestService]);
 * ```
 *
 * ## Angular 2 code: `Ng2TestService` as an entry point for `Http`
 * Use `angular-http-harness/ng2`
 *
 * ```
 * import {HttpHarness} from "angular-http-harness";
 * import {fromNg2} from "angular-http-harness/ng2";
 *
 * @Injectable()
 * export class Ng2TestService extends TestService {
 *
 *     constructor(_http: Http) {
 *         super(new HttpHarness(fromNg2(_http)));
 *     }
 *
 *     get(id: string): Observable<TestModel> {
 *         return super.get(id).map(resp => resp.json());
 *     }
 * }
 */
var HttpHarness = (function () {
    function HttpHarness(_http) {
        this._http = _http;
    }
    HttpHarness.prototype.get = function (url, options) {
        return this._http.get(url, options);
    };
    HttpHarness.prototype.post = function (url, body, options) {
        return this._http.post(url, body, options);
    };
    HttpHarness.prototype.put = function (url, body, options) {
        return this._http.put(url, body, options);
    };
    HttpHarness.prototype.delete = function (url, options) {
        return this._http.delete(url, options);
    };
    return HttpHarness;
}());
exports.HttpHarness = HttpHarness;
